Crate ckb_rich_indexer

Crate ckb_rich_indexer 

CKB’s built-in rich-indexer, based on relational database, which shares data with the ckb node by creating secondary db instances.

Structs

AsyncRichIndexerHandle
Async handle to the rich-indexer.
RichIndexerHandle
Handle to the rich-indexer.
RichIndexerService
Rich-Indexer service