CKB’s built-in rich-indexer, based on relational database, which shares data with the ckb node by creating secondary db instances.
Structs
- Async
Rich Indexer Handle - Async handle to the rich-indexer.
- Rich
Indexer Handle - Handle to the rich-indexer.
- Rich
Indexer Service - Rich-Indexer service